Django Hizashi project utilities
================================

A set of helper utilities for managing Django Hizashi project environment.


initproject
-----------

To initialize a new project execute:

    hizashi.py initproject my_new_project_name

Optional parameters:

* *template* - path or url for a Django project template, defaults to https://github.com/dodobas/hizashi-project-template/archive/master.zip


initapp
-------

To initialize a new application execute:

    hizashi.py initapp my_new_application_name

Optional parameters:

* *template* - path or url for a Django application template, defaults to https://github.com/dodobas/hizashi-application-template/archive/master.zip
